==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Input/mpeg/translations/mpeg_plugin_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_RS">
<context>
    <name>DecoderMPEGFactory</name>
    <message>
        <location filename="../decodermpegfactory.cpp" line="178"/>
        <source>MPEG Plugin</source>
        <translation>МПЕГ прикључак</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="181"/>
        <source>MPEG Files</source>
        <translation>МПЕГ фајлови</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="397"/>
        <source>About MPEG Audio Plugin</source>
        <translation>О МПЕГ прикључку</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="398"/>
        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="399"/>
        <source>Compiled against:</source>
        <translation>Компилован на:</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="408"/>
        <source>mpg123, API version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="412"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="413"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Заснован на пројектима mq3 и madplay</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="71"/>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <location filename="../mpegmetadatamodel.cpp" line="77"/>
        <location filename="../mpegmetadatamodel.cpp" line="80"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="83"/>
        <source>Protection</source>
        <translation>Заштита</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <source>Copyright</source>
        <translation>Ауторско право</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="85"/>
        <source>Original</source>
        <translation>Оригинал</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Поставке МПЕГ прикључка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>MAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>MPG123</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Tag Priority</source>
        <translation>Приоритет ознака</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>First:</source>
        <translation>Прва:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <location filename="../settingsdialog.ui" line="158"/>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>ID3v1</source>
        <translation>ИД3в1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <location filename="../settingsdialog.ui" line="163"/>
        <location filename="../settingsdialog.ui" line="212"/>
        <source>ID3v2</source>
        <translation>ИД3в2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="119"/>
        <location filename="../settingsdialog.ui" line="168"/>
        <location filename="../settingsdialog.ui" line="217"/>
        <source>APE</source>
        <translation>ЕЈП</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <location filename="../settingsdialog.ui" line="222"/>
        <source>Disabled</source>
        <translation>онемогућена</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>Second:</source>
        <translation>Друга:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="187"/>
        <source>Third:</source>
        <translation>Трећа:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="252"/>
        <source>Encodings</source>
        <translation>Кодирање</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="264"/>
        <source>ID3v1 encoding:</source>
        <translation>ИД3в1 кодирање:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="290"/>
        <source>ID3v2 encoding:</source>
        <translation>ИД3в2 кодирање:</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/Input/mpeg/translations/mpeg_plugin_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_RS">
<context>
    <name>DecoderMPEGFactory</name>
    <message>
        <location filename="../decodermpegfactory.cpp" line="183"/>
        <source>MPEG Plugin</source>
        <translation>МПЕГ прикључак</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="186"/>
        <source>MPEG Files</source>
        <translation>МПЕГ фајлови</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="424"/>
        <source>About MPEG Audio Plugin</source>
        <translation>О МПЕГ прикључку</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="425"/>
        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="426"/>
        <source>Compiled against:</source>
        <translation>Компилован на:</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="435"/>
        <source>mpg123, API version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="439"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="440"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Заснован на пројектима mq3 и madplay</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <location filename="../mpegmetadatamodel.cpp" line="75"/>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <source>Protection</source>
        <translation>Заштита</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="85"/>
        <source>Copyright</source>
        <translation>Ауторско право</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="86"/>
        <source>Original</source>
        <translation>Оригинал</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Поставке МПЕГ прикључка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>MAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>MPG123</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Enable CRC checking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Tag Priority</source>
        <translation>Приоритет ознака</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>First:</source>
        <translation>Прва:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="119"/>
        <location filename="../settingsdialog.ui" line="168"/>
        <location filename="../settingsdialog.ui" line="217"/>
        <source>ID3v1</source>
        <translation>ИД3в1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <location filename="../settingsdialog.ui" line="222"/>
        <source>ID3v2</source>
        <translation>ИД3в2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="129"/>
        <location filename="../settingsdialog.ui" line="178"/>
        <location filename="../settingsdialog.ui" line="227"/>
        <source>APE</source>
        <translation>ЕЈП</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="134"/>
        <location filename="../settingsdialog.ui" line="183"/>
        <location filename="../settingsdialog.ui" line="232"/>
        <source>Disabled</source>
        <translation>онемогућена</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="148"/>
        <source>Second:</source>
        <translation>Друга:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="197"/>
        <source>Third:</source>
        <translation>Трећа:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="253"/>
        <source>Merge selected tag types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="272"/>
        <source>Encodings</source>
        <translation>Кодирање</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="333"/>
        <source>ID3v1 encoding:</source>
        <translation>ИД3в1 кодирање:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="343"/>
        <source>Try to detect encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="294"/>
        <source>ID3v2 encoding:</source>
        <translation>ИД3в2 кодирање:</translation>
    </message>
</context>
</TS>
